// generated 2006/7/2 10:40:43 E. Europe Standard Time
// using glademm V2.6.0_20041003_win32
//
// newer (non customized) versions of this file go to toolbar2.hh_new

// you might replace
//    class foo : public foo_glade { ... };
// by
//    typedef foo_glade foo;
// if you didn't make any modifications to the widget

#ifndef _TOOLBAR2_HH
#  include "toolbar2_glade.hh"
#  define _TOOLBAR2_HH
class toolbar2 : public toolbar2_glade
{  
public:
        
        toolbar2(GlademmData *gmm_data) : toolbar2_glade(gmm_data)
        {  
        }
};
#endif
