#if !defined CONFIG_HH
#define CONFIG_HH

#define LANG1_LANG2 "Ro-En"
#define LANG2_LANG1 "En-Ro"
#define LIST1_LIST2 "Ro_En"
#define LIST2_LIST1 "En_Ro"

/* For built on Linux platform*/
#define LINUX_PLATFORM

/* For built on Windows platform*/
//#define WINDOWS_PLATFORM

#if defined LINUX_PLATFORM
#	define WORDLIST_RELATIVE_PATH "/share/qdict/wordlists"
#else
#	define WORDLIST_RELATIVE_PATH "\\share\\qdict\\wordlists"
#endif

#endif
