// generated 2006/7/2 10:40:43 E. Europe Standard Time
// using glademm V2.6.0_20041003_win32
//
// newer (non customized) versions of this file go to toolbar2.cc_new

// This file is for your program, I won't touch it again!

#include "../config.h"
#include "toolbar2.hh"
