// generated 2006/7/2 10:40:43 E. Europe Standard Time
// using glademm V2.6.0_20041003_win32
//
// DO NOT EDIT THIS FILE ! It was created using
// glade-- E:\Temp\Temp\Qdict~\qdict.glade
// for gtk 2.8.8 and gtkmm 2.8.8
//
// Please modify the corresponding derived classes in ./src/toolbar2.hh and./src/toolbar2.cc

#ifndef _TOOLBAR2_GLADE_HH
#  define _TOOLBAR2_GLADE_HH

// Since all your widgets were private I made them all public.
// To differentiate between accessable (e.g. entries, output labels)
// and unaccessible widgets (e.g. static labels, containers)
// you should use the 'visibility' property (only visible in C++ mode)


#if !defined(GLADEMM_DATA)
#define GLADEMM_DATA 
#include <gtkmm/accelgroup.h>

class GlademmData
{  
        
        Glib::RefPtr<Gtk::AccelGroup> accgrp;
public:
        
        GlademmData(Glib::RefPtr<Gtk::AccelGroup> ag) : accgrp(ag)
        {  
        }
        
        Glib::RefPtr<Gtk::AccelGroup>  getAccelGroup()
        {  return accgrp;
        }
};
#endif //GLADEMM_DATA

#include <gtkmm/toolbar.h>
#include <gtkmm/tooltips.h>
#include <gtkmm/button.h>
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#include <gtkmm/toolitem.h>
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //

class toolbar2_glade : public Gtk::Toolbar
{  
public:
        
        Gtk::Tooltips _tooltips;
        class Gtk::Toolbar * toolbar2;
        class Gtk::Button * button10;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem10;
#endif //
        class Gtk::Button * button11;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem11;
#endif //
        class Gtk::Button * button12;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem12;
#endif //
        class Gtk::Button * button13;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem13;
#endif //
        class Gtk::Button * button14;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem14;
#endif //
        class Gtk::Button * button15;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem15;
#endif //
        class Gtk::Button * button16;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem16;
#endif //
        class Gtk::Button * button17;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem17;
#endif //
        class Gtk::Button * button18;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem18;
#endif //
        class Gtk::Button * button19;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem19;
#endif //
protected:
        
        toolbar2_glade(GlademmData *gmm_data);
        
        ~toolbar2_glade();
};
#endif
