/***************************************************************************
 *   Copyright (C) 2006 by Alexandru Olaru                                 *
 *   qumbetlian@yahoo.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _QDICT_HELP_HH
#  define _QDICT_HELP_HH

#include <gtkmm/dialog.h>
#include <gtkmm/button.h>
#include <gtkmm/buttonbox.h>
#include <gtkmm/textview.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/label.h>
#include <gtkmm/box.h>
#include <gtkmm/image.h>
#include <gtkmm/notebook.h>

class QdictHelp : public Gtk::Dialog
{
    protected:
        class Gtk::Dialog * qdict_help;
        class Gtk::Button * closebutton1;
        class Gtk::TextView * textview1;
        class Gtk::ScrolledWindow * scrolledwindow1;
        class Gtk::Label * Help;
        class Gtk::Label * label1;
        class Gtk::Label * label2;
        class Gtk::Label * label3;
        class Gtk::VBox * vbox1;
        class Gtk::Label * About;
        class Gtk::Label * label5;
        class Gtk::Image * image1;
        class Gtk::Label * label6;
        class Gtk::VBox * vbox2;
        class Gtk::Label * Autor;
        class Gtk::Notebook * notebook1;
        Glib::RefPtr<Gdk::Pixbuf> my_image;
    public:
        QdictHelp();
        ~QdictHelp();
        void on_close(void);
        int run(Pango::FontDescription fd, const char *lang1_lang2,
                unsigned int lang1_lang2_nitems, const char *lang2_lang1,
                unsigned int lang2_lang1_nitems);
        };
#endif
