/***************************************************************************
 *   Copyright (C) 2006 by Alexandru Olaru                                 *
 *   qumbetlian@yahoo.com                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _MAINWINDOW_GLADE_HH
#  define _MAINWINDOW_GLADE_HH

#if !defined(GLADEMM_DATA)
#define GLADEMM_DATA
#include <gtkmm/accelgroup.h>

class GlademmData
{

        Glib::RefPtr<Gtk::AccelGroup> accgrp;
public:

        GlademmData(Glib::RefPtr<Gtk::AccelGroup> ag) : accgrp(ag)
        {
        }

        Glib::RefPtr<Gtk::AccelGroup>  getAccelGroup()
        {  return accgrp;
        }
};
#endif //GLADEMM_DATA

#include <gtkmm/window.h>
#include <gtkmm/image.h>
#include <gtkmm/label.h>
#include <gtkmm/box.h>
#include <gtkmm/alignment.h>
#include <gtkmm/button.h>
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#include <gtkmm/toolitem.h>
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
#endif //
#include <gtkmm/toolbar.h>
#include <gtkmm/radiobutton.h>
#include <gtkmm/handlebox.h>
#include "config.hh"
#include "../config.h"
#include "toolbar2.hh"
#include "treeviewdict.hh"

class entry1;

#include <gtkmm/togglebutton.h>

class treeview1;

#include <gtkmm/scrolledwindow.h>

class textview1;

class mainwindow_glade : public Gtk::Window
{
public:
        class Gtk::Window * mainwindow;
        class Gtk::Image * image1;
        class Gtk::Label * label1;
        class Gtk::HBox * hbox4;
        class Gtk::Alignment * alignment1;
        class Gtk::Button * button1;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem1;
#endif //
        class Gtk::Image * image2;
        class Gtk::Label * label2;
        class Gtk::HBox * hbox5;
        class Gtk::Alignment * alignment2;
        class Gtk::Button * button2;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem2;
#endif //
        class Gtk::Image * image3;
        class Gtk::Label * label3;
        class Gtk::HBox * hbox6;
        class Gtk::Alignment * alignment3;
        class Gtk::Button * button3;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem3;
#endif //
        class Gtk::Image * image4;
        class Gtk::Label * label4;
        class Gtk::HBox * hbox7;
        class Gtk::Alignment * alignment4;
        class Gtk::Button * button4;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem4;
#endif //
        class Gtk::Image * image5;
        class Gtk::Label * label5;
        class Gtk::HBox * hbox8;
        class Gtk::Alignment * alignment5;
        class Gtk::Button * button5;
#if GTKMM_MAJOR_VERSION==2 && GTKMM_MINOR_VERSION>2
        class Gtk::ToolItem * toolitem5;
#endif //
        class Gtk::Toolbar * toolbar1;
        class Gtk::RadioButton * radiobutton1;
        class Gtk::RadioButton * radiobutton2;
        class toolbar2 * toolbar2;
        class Gtk::HandleBox * handlebox1;
        class Gtk::HBox * hbox3;
        class entry1 * entry1;
        class Gtk::ToggleButton * togglebutton1;
        class Gtk::HBox * hbox2;
        class TreeViewDict * treeviewdict1;
        class Gtk::ScrolledWindow * scrolledwindow1;
        class Gtk::VBox * vbox2;
        class textview1 * textview1;
        class Gtk::HBox * hbox1;
        class Gtk::VBox * vbox1;
protected:
        GlademmData *gmm_data;

        mainwindow_glade();
        ~mainwindow_glade();
        void show(void);
};

#include <gtkmm/entry.h>

class entry1_glade : public Gtk::Entry
{
public:

        class Gtk::Entry * entry1;
protected:

        entry1_glade(GlademmData *gmm_data);

        ~entry1_glade();
};

#include <gtkmm/textview.h>

class textview1_glade : public Gtk::TextView
{
public:

        class Gtk::TextView * textview1;
protected:

        textview1_glade(GlademmData *gmm_data);

        ~textview1_glade();
};
#endif
